@@ -5,9 +5,11 @@
 
 //Dean Bodenham June 2016
 
+#include<iostream>
 #include<vector>
 //for sort
 #include<algorithm>
+#include<math.h>
 
 //NOTE:
 //'difficult' part was sorting the three vectors pvalue, tau and l according the the order in pvalue. Although it would have been relatively straightforward to use the sort function and a lambda function, for some reason the g++ compiler on MAc OSX (gcc 4.2) would not accept this. Then, after installing g++ 4.5, it created other errors. In the end, I decided to make a pair of pvalue and a perm vector (could have used iota), sort the pair, and then extract the permutation half of the pair. Later, access elements of the three vectors according to the permutation order.
